unit Unit1;

{$mode objfpc}{$H+}

interface

uses
  Classes, SysUtils, IniFiles, FileUtil, Forms, Controls, Graphics, Dialogs,
  StdCtrls, EditBtn, ExtCtrls, IDEImageConsistencyChecks, Types;

type

  { TForm1 }

  TForm1 = class(TForm)
    Button1: TButton;
    DirectoryEdit1: TDirectoryEdit;
    Label1: TLabel;
    ListBox1: TListBox;
    Panel1: TPanel;
    procedure Button1Click(Sender: TObject);
    procedure DirectoryEdit1AcceptDirectory(Sender: TObject; Var Value: String);
    procedure FormCreate(Sender: TObject);
    procedure FormDestroy(Sender: TObject);
    procedure ListBox1DrawItem(Control: TWinControl; Index: Integer;
      ARect: TRect; State: TOwnerDrawState);
    procedure ListBox1ShowHint(Sender: TObject; HintInfo: PHintInfo);
  private
    FIniFile: String;
    FLazarusImagesDirectory: String;
    FIDEImageConsistencyCheck: TIDEImageConsistencyCheck;
    procedure ConsistencyCheckInconsistency(const Str: String;
      Inconsistency: TInconsistency);
    procedure InitControls;
    procedure LoadIni;
    procedure SaveIni;
  end;

var
  Form1: TForm1;

implementation

{$R *.lfm}

{ TForm1 }

procedure TForm1.FormCreate(Sender: TObject);
begin
  FIniFile := GetTempDir + 'IDEImagesConsistency.ini';
  LoadIni;
  InitControls;
end;

procedure TForm1.FormDestroy(Sender: TObject);
begin
  SaveIni;
end;

procedure TForm1.ListBox1DrawItem(Control: TWinControl; Index: Integer;
  ARect: TRect; State: TOwnerDrawState);
begin
  case TInconsistency(ListBox1.Items.Objects[Index]) of
    icNotPhysicalAvailable:  ListBox1.Canvas.Font.Color := clRed;
    icNotInResourceFileList: ListBox1.Canvas.Font.Color := clPurple;
  else
    ListBox1.Canvas.Font.Color := clBlack;
  end;
  ListBox1.Canvas.FillRect(ARect);
  ListBox1.Canvas.TextRect(ARect, ARect.Left, ARect.Top, ListBox1.Items[Index]);
end;

procedure TForm1.ListBox1ShowHint(Sender: TObject; HintInfo: PHintInfo);
var
  ListBoxItemIndex: Integer;
begin
  ListBoxItemIndex := ListBox1.GetIndexAtY(HintInfo^.CursorPos.y);
  if ListBoxItemIndex < 0 then Exit;
  HintInfo^.HintStr := InconsistencyStrings[TInconsistency(ListBox1.Items.Objects[ListBoxItemIndex])];
end;

procedure TForm1.DirectoryEdit1AcceptDirectory(Sender: TObject;
  Var Value: String);
begin
  FLazarusImagesDirectory := Value;
end;

procedure TForm1.Button1Click(Sender: TObject);
begin
  ListBox1.Clear;
  FIDEImageConsistencyCheck := TIDEImageConsistencyCheck.Create;
  try
    FIDEImageConsistencyCheck.ImagesDirectory := FLazarusImagesDirectory;
    FIDEImageConsistencyCheck.OnInconsistency := @ConsistencyCheckInconsistency;
    FIDEImageConsistencyCheck.StartCheck;
  finally
    FIDEImageConsistencyCheck.Free;
  end;
end;

procedure TForm1.InitControls;
begin
  DirectoryEdit1.Text := FLazarusImagesDirectory;
end;

procedure TForm1.ConsistencyCheckInconsistency(const Str: String;
  Inconsistency: TInconsistency);
begin
  ListBox1.AddItem(Str, TObject(Inconsistency));
end;

procedure TForm1.LoadIni;
var
  Ini: TIniFile;
begin
  Ini := TIniFile.Create(FIniFile);
  try
    FLazarusImagesDirectory := Ini.ReadString('Main', 'LazarusImagesDirectory', '');
  except
    on e: Exception do
      ShowMessage('TForm1.LoadIni: ' + e.Message);
  end;
  Ini.Free;
end;

procedure TForm1.SaveIni;
var
  Ini: TIniFile;
begin
  Ini := TIniFile.Create(FIniFile);
  try
    Ini.WriteString('Main', 'LazarusImagesDirectory', FLazarusImagesDirectory);
  except
    on e: Exception do
      ShowMessage('TForm1.SaveIni: ' + e.Message);
  end;
  Ini.Free;
end;

end.

